SpiMasterDmaChannel

Trait SpiMasterDmaChannel 

pub trait SpiMasterDmaChannel<'d, S>: Sealed + Into<SpiDmaChannel<'d>> { }
Available on crate feature unstable only.
DMA channel trait for SPI peripherals.

Implemented for each channel type that can serve a particular SPI instance S.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<'d> SpiMasterDmaChannel<'d, SPI2<'d>> for SpiDmaChannel<'d>

Source

impl<'d> SpiMasterDmaChannel<'d, SPI2<'d>> for DMA_SPI2<'d>

Source

impl<'d> SpiMasterDmaChannel<'d, SPI3<'d>> for SpiDmaChannel<'d>

Source

impl<'d> SpiMasterDmaChannel<'d, SPI3<'d>> for DMA_SPI3<'d>

Source

impl<'d> SpiMasterDmaChannel<'d, AnySpi<'d>> for SpiDmaChannel<'d>

Source

impl<'d> SpiMasterDmaChannel<'d, AnySpi<'d>> for DMA_SPI2<'d>

Source

impl<'d> SpiMasterDmaChannel<'d, AnySpi<'d>> for DMA_SPI3<'d>